import babel from 'rollup-plugin-babel';
import commonjs from 'rollup-plugin-commonjs';
import postcss from 'rollup-plugin-postcss';
import autoprefixer from 'autoprefixer';
import cssnano from 'cssnano';
import vue from 'rollup-plugin-vue';
import { terser } from 'rollup-plugin-terser';
// import resolve from '@rollup/plugin-node-resolve';

const configFn = (name) => ({
    plugins: [
        vue(),
        babel({
            exclude: 'node_modules/**',
            runtimeHelpers: true,
        }),
        commonjs(),
        postcss({
            plugins: [autoprefixer(), cssnano()],
            extract: `theme-chalk/${name}.css`,
        }),
        terser(),
        // resolve(),
    ],
    external: [
        //外部库， 使用'umd'文件时需要先引入这个外部库
        'vue',
    ],
});

const umdConfig = {
    input: './packages/index.js',
    output: [
        {
            file: './dist/my-lib-umd.js',
            format: 'umd',
            name: 'myLib',
        },
        {
            file: './dist/my-lib-es.js',
            format: 'es',
        },
        {
            file: './dist/my-lib-cjs.js',
            format: 'cjs',
        },
    ],
    ...configFn('index'),
};
// umdConfig.plugins.unshift(del({ targets: ['lib/*', 'dist/*'] }));

export default umdConfig;
